{% extends original_template_name %}
{% load wagtailadmin_tags i18n %}

{% block add_button %}
    <div class="wai-chooser-panel__buttons">
        {{ block.super }}

        <button
            type="button"
            class="button button-small button-secondary chooser__choose-button wai-chooser-panel__button-suggest"
            data-wai-chooser-panel-target="suggestButton"
            data-action="click->wai-chooser-panel#suggest">
            {% icon name=icon|default:"wand" %}
            <span class="wai-chooser-panel__suggest-label">
                {% translate "Suggest" %}
            </span>
            <span class="wai-chooser-panel__suggest-more-label">
                {% translate "Suggest different" %}
            </span>
            <span class="wai-chooser-panel__no-more-label">
                {% translate "No results remaining" %}
            </span>
        </button>
        <button
            type="button"
            class="button button-small button-secondary chooser__choose-button wai-chooser-panel__button-clear"
            data-action="click->wai-chooser-panel#clear">
            {% translate "Clear suggestions" %}
        </button>
    </div>
{% endblock %}
