# Generated by Django 4.2.25 on 2025-10-09 08:05

from django.db import migrations, models

import wagtail_ai.models


class Migration(migrations.Migration):
    dependencies = [
        ("wagtail_ai", "0002_populate_default_prompts"),
    ]

    operations = [
        migrations.CreateModel(
            name="AgentSettings",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "page_title_prompt",
                    models.TextField(
                        blank=True,
                        default=wagtail_ai.models.AgentPromptDefaults.page_title_prompt,
                    ),
                ),
                (
                    "page_description_prompt",
                    models.TextField(
                        blank=True,
                        default=wagtail_ai.models.AgentPromptDefaults.page_description_prompt,
                    ),
                ),
                (
                    "image_title_prompt",
                    models.TextField(
                        blank=True,
                        default=wagtail_ai.models.AgentPromptDefaults.image_title_prompt,
                    ),
                ),
                (
                    "image_description_prompt",
                    models.TextField(
                        blank=True,
                        default=wagtail_ai.models.AgentPromptDefaults.image_description_prompt,
                    ),
                ),
                (
                    "contextual_alt_text_prompt",
                    models.TextField(
                        blank=True,
                        default=wagtail_ai.models.AgentPromptDefaults.contextual_alt_text_prompt,
                    ),
                ),
                ("content_feedback_prompt", models.TextField(blank=True)),
                (
                    "content_feedback_content_type",
                    models.CharField(
                        choices=[("text", "Plain text"), ("html", "HTML")],
                        default="html",
                        max_length=64,
                    ),
                ),
            ],
            options={
                "verbose_name": "Agents",
                "abstract": False,
            },
        ),
    ]
